package com.gavin;

import java.util.ArrayList;
import java.util.List;

import com.gavin.function.GavinTestFunction;
import com.yindangu.v3.plugin.vds.reg.api.IRegisterPlugin;
import com.yindangu.v3.plugin.vds.reg.api.builder.IComponentProfileBuilder;
import com.yindangu.v3.plugin.vds.reg.api.builder.IFunctionBuilder;
import com.yindangu.v3.plugin.vds.reg.api.builder.IFunctionBuilder.IFuncInputBuilder;
import com.yindangu.v3.plugin.vds.reg.api.builder.IFunctionBuilder.IFuncOutputBuilder;
import com.yindangu.v3.plugin.vds.reg.api.model.IComponentProfileVo;
import com.yindangu.v3.plugin.vds.reg.api.model.IFunctionProfileVo;
import com.yindangu.v3.plugin.vds.reg.api.model.IPluginProfileVo;
import com.yindangu.v3.plugin.vds.reg.api.model.VariableType;
import com.yindangu.v3.plugin.vds.reg.api.model.IFunctionProfileVo.IFunctionInputVo;
import com.yindangu.v3.plugin.vds.reg.api.model.IFunctionProfileVo.IFunctionOutputVo;
import com.yindangu.v3.plugin.vds.reg.common.RegVds;

public class GavinTestFunctionPluginRegister implements IRegisterPlugin {

    @Override
    public IComponentProfileVo getComponentProfile() {
        //  构造构件元信息
        IComponentProfileBuilder componentProfileBuilder = RegVds.getPlugin().getComponentProfile();
        componentProfileBuilder.setGroupId("com.gavin");
        componentProfileBuilder.setCode("GavinTestVFunctionPluginComponent");      
        IComponentProfileVo componentProfileVo = componentProfileBuilder.build();

        return componentProfileVo;
    }

    @Override
    public List<IPluginProfileVo> getPluginProfile() {

        IFunctionProfileVo functionProfile = createTestFunction();

        List<IPluginProfileVo> profileLst = new ArrayList<IPluginProfileVo>();
        profileLst.add(functionProfile);

        return profileLst;
    }

    /**
     * 创建测试后台函数
     * @return
     */
    private IFunctionProfileVo createTestFunction() {
        IFunctionBuilder functionBuilder = RegVds.getPlugin().getFunctiontPlugin();	
        functionBuilder.setCode(GavinTestFunction.class.getSimpleName());
        functionBuilder.setName("Gavin测试验证-后端函数");
        functionBuilder.setDesc("本函数用于测试验证后端函数");
        functionBuilder.setAuthor("huangjr");
        functionBuilder.setEntry(GavinTestFunction.class);

        IFunctionInputVo inputParamVoOne = createFunctionInputVo(functionBuilder, "第一个参数", VariableType.Char);
        IFunctionInputVo inputParamVoTwo = createFunctionInputVo(functionBuilder, "第二个参数", VariableType.Char);
        IFunctionInputVo inputParamVoThree = createFunctionInputVo(functionBuilder, "第三个参数", VariableType.Char);
        functionBuilder.addInputParam(inputParamVoOne);
        functionBuilder.addInputParam(inputParamVoTwo);
        functionBuilder.addInputParam(inputParamVoThree);

        IFunctionOutputVo outputParamVo = createFunctionOutputVo(functionBuilder, "函数返回参数", VariableType.Char);
        functionBuilder.setOutput(outputParamVo);
        IFunctionProfileVo functionProfile = functionBuilder.build();
        return functionProfile;
    }

    /**
     * 创建后台函数输入参数
     * @param functionBuilder
     * @param desc
     * @param type
     * @return
     */
    private IFunctionInputVo createFunctionInputVo(IFunctionBuilder functionBuilder, String desc, VariableType type) {
        IFuncInputBuilder inputParamBuilder = functionBuilder.newInput();
        inputParamBuilder.setType(type);
        inputParamBuilder.setDesc(desc);
        IFunctionInputVo inputParamVo = inputParamBuilder.build();
        return inputParamVo;
    }

    /**
     * 创建后台函数输出参数
     * @param functionBuilder
     * @param desc
     * @param type
     * @return
     */
    private IFunctionOutputVo createFunctionOutputVo(IFunctionBuilder functionBuilder, String desc, VariableType type) {
        IFuncOutputBuilder outputParamBuilder = functionBuilder.newOutput();
        outputParamBuilder.setType(type);
        outputParamBuilder.setDesc(desc);
        IFunctionOutputVo outputParamVo = outputParamBuilder.build();
        return outputParamVo;
    }
    
}